@@ -23,7 +23,7 @@
 //  @licend The above is the entire license notice for the JavaScript
 //  code in this page (or file).
 //
-// @source http://e-valkov.org/linterna-magica
+// @source http://linterna-magica.nongnu.org
 
 // END OF LICENSE HEADER
 
@@ -251,6 +251,14 @@ LinternaMagica.prototype.extract_objects_from_dom = function(element)
 			self.request_video_link.apply(self,[data]);
 		    }, this.wait_dailymotion);
 		}
+		else if (!/blip\.tv/i.test(window.location.hostname) &&
+			 ((object.hasAttribute('src') &&
+			  /blip\.tv/i.test(object.getAttribute('src'))) ||
+			 (object.hasAttribute('data') && 
+			  /blip\.tv/i.test(object.getAttribute('data')))))
+		{
+		    this.request_bliptv_jsonp_data(object_data);
+		}
 		else
 		{
 		    this.request_video_link(object_data);
@@ -273,8 +281,10 @@ LinternaMagica.prototype.extract_objects_from_dom = function(element)
 // Find the flash object width
 LinternaMagica.prototype.extract_object_width = function(element)
 {
-    if (!/HTML(embed|object)element/i.test(element))
+    if (!/HTML(embed|iframe|object)element/i.test(element))
+    {
 	return null;
+    }
     // Bug see comments in is_swf_object
     // if (typeof(element) !== "object")
     // 	return null;
@@ -315,8 +325,11 @@ LinternaMagica.prototype.extract_object_width = function(element)
 // Find the flash object height
 LinternaMagica.prototype.extract_object_height = function(element)
 {
-    if (!/HTML(embed|object)element/i.test(element))
+    if (!/HTML(embed|iframe|object)element/i.test(element))
+    {
 	return null;
+    }
+
     // Bug see comments in is_swf_object
     // if (typeof(element) !== "object")
     // 	return null;
