@@ -23,7 +23,7 @@
 //  @licend The above is the entire license notice for the JavaScript
 //  code in this page (or file).
 //
-// @source http://e-valkov.org/linterna-magica
+// @source http://linterna-magica.nongnu.org
 
 // END OF LICENSE HEADER
 
@@ -162,6 +162,16 @@ LinternaMagica.prototype.request_video_link = function(object_data)
 	address = "/player/cbplayer/settings.php?vid="+video_id;
     }
 
+    if (/theonion\.com/i.test(host))
+    {
+	address = "/ajax/onn/embed/"+video_id+".json";
+    }
+
+    if (/blip\.tv/i.test(host))
+    {
+	address="/rss/flash/"+video_id;
+    }
+
     var self = this;
     client.onreadystatechange = function() {
 	var client = this;
@@ -437,6 +447,41 @@ function(client, object_data)
 	    }
 	}
 
+	if (/theonion\.com/i.test(host))
+	{
+	    var onion_data = eval("("+client.responseText+")");
+	    url = onion_data.video_url;
+	}
+
+	if (/blip\.tv/i.test(host))
+	{
+	    // All the data is available in the XML, but it is not a
+	    // good idea to support the site in two places. JSON is
+	    // easier. The drawback is two requests.
+	    try
+	    {
+		var embed_id =
+		    xml.getElementsByTagName("embedLookup");
+
+		// Firefox
+		if (embed_id && typeof(embed_id[0]) == "undefined")
+		{
+		    embed_id = 
+			xml.getElementsByTagName("blip:embedLookup");
+		}
+
+		object_data.video_id = embed_id[0].textContent;
+		this.request_bliptv_jsonp_data(object_data);
+	    }
+	    catch(e)
+	    {
+		this.log("LinternaMagica.prototype.request_video"+
+			 "_link_parse_response:\n"+
+			 "Exception in Blip.tv while parsing XML",1);
+	    }
+	    return null;
+	}
+
 	if (!url)
 	{
 	    return;
